pub struct MitmConfig {
pub ca_storage_path: PathBuf,
pub max_connections: usize,
pub connection_timeout: u64,
pub interceptor_timeout_secs: u64,
pub upstream_proxy: Option<Proxy>,
}Expand description
Configuration for MITM proxy
Fields
ca_storage_path: PathBufPath to store CA certificates
max_connections: usizeMaximum concurrent connections
connection_timeout: u64Connection timeout in seconds
interceptor_timeout_secs: u64Interceptor timeout in seconds. Each interceptor is given this duration to process a request/response; if it exceeds the timeout it will be skipped to avoid blocking the proxy.
upstream_proxy: Option<Proxy>Optional upstream proxy (supports HTTP, HTTPS, SOCKS5, SOCKS5h) Example: “socks5h://127.0.0.1:1080” or “http://proxy.example.com:8080”